| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Binrep.Instances.Strongweak.SWChain
Contents
Description
binrep instances for SWChain where Cls a => Cls (.SWChain n a)
SW and SWChain can help define binreppable data types plus an "easy to work
with" representation in one fell swoop. SWChain is a meaningless newtype only
there to help strongweak do its work (without having to write instances
manually). So here, we define a bunch of recursive instances that use the inner
type.